@@ -4,14 +4,17 @@
 # rewriten MARCH 2018 by Mikis
 # TO DO
 # 
-#-------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # log log Survival plots
 # there are three functions for that plus one which connect them al
 # i)   loglogSurv1()  : method 2 for for type I tails (log WEI)
 # ii)  loglogSurv2()  : method 2 for type II tails (WEI)
 # iii) loglogSurv3()  : method 2 for type III tails (GUMBEL)
 # iv)  loglogSurv     : combines the above functions and selects the best
-#-------------------------------------------------------------------------------
+################################################################################
 # log Survival plot
 # v)    logSurv() : plots the empirical survival function log(1-ecdf) 
 #        against log(y) for part or all of the data and fits three linear model
@@ -22,25 +25,23 @@
 #       
 #-------------------------------------------------------------------------------
 # those are in gamlss.tr
-# vii)     fitTail : fits a truncated gamlss.family distribution to the tail of the data
+# vii)  fitTail : fits a truncated gamlss.family distribution to the tail of the data
 # viii) fitTailAll : fits a (Hill type) series of Fit using the fitTail function 
-#------------------------------------------------------------------------------- 
-#-------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # TYPE I
-#---------------------------------------------------------------------------
-#---------------------------------------------------------------------------
+################################################################################
 loglogSurv1 <- function(y, 
                          prob = 0.9, 
                          print = TRUE,
                          title = NULL,
-                         lcol = gray(.1),
+                          lcol = gray(.1),
                          ltype = 1,
                         ...)
 {
-  #-----------------
+#-----------------
   Xlab1 <- paste("log(log(", deparse(substitute(y)), "))", sep="")
     cdF <- ECDF(y) # get ecdf for all data
      mY <- quantile(y, probs=prob)
@@ -68,10 +69,12 @@ howmany <- length(Y)
     } else title(title)
   invisible(m1)  
 }
-
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # Type II
-#--------------------------------------------------------------------------------
+################################################################################
 loglogSurv2 <- function(y, 
                           prob = 0.9, 
                          print = TRUE,
@@ -108,9 +111,12 @@ howmany <- length(Y)
   } else title(title)
   invisible(m1)  
 }
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # Type III
-#--------------------------------------------------------------------------------
+################################################################################
 loglogSurv3 <- function(y, 
                      prob = 0.9, 
                     print = TRUE,
@@ -147,11 +153,12 @@ loglogSurv3 <- function(y,
   } else title(title)
   invisible(m1)  
 }
-#--------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # Select the best from type I II and III
-#--------------------------------------------------------------------------------
-#--------------------------------------------------------------------------------
+################################################################################
 loglogSurv <- function(y, 
                  prob = 0.9, 
                 print = TRUE,
@@ -236,14 +243,15 @@ if (plot)
 model <- switch(num, m1,m2,m3)   
 return(model) 
 }
-#-----------------------------------------------------------------------------
-#-----------------------------------------------------------------------------
-#-----------------------------------------------------------------------------
-#-----------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # this plots the empirical log(1-ecdf) agains log(y)
 # The complementary cumulative distribution function (CCDF) plot
-# fits also a linear and a quadraitic fit to the resulting plot yo help interpetation 
-#----------------------------------------------------------------------------- 
+# fits also a linear and a quadraitic fit to the resulting plot yo help 
+# interpretation 
+################################################################################
 logSurv <- function(y, 
                   prob = 0.9, 
                   tail = c("right", "left"), 
@@ -316,15 +324,11 @@ if (lines)
       legend(place, legend=c("linear", "quadratic", "exponential"), col=lcol, lty=ltype, lwd=2 )
     }
   }
-    # if (lines)
-    # {
-    #   M <-rbind(coef(m1), coef(m2)[-2], coef(m3))
-    #   rownames(M) <- c("linear", "quadratic", "exponential")
-    #  # invisible(M) 
-    # }
 }
-#-------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # THE SAME AS logSurv() WITHOUT FITTING MODELS 
 logSurv0 <- function(y, 
                      prob = 0.9, 
@@ -375,8 +379,10 @@ howmany <- length(Y)
   rownames(M) <- c("logS", "logy")
   invisible(M) 
 }
-#-------------------------------------------------------------------------------
-#-------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 loglogplot <- function(y, nplus1=TRUE, ...)
 {
   Xlab <- paste("log(", deparse(substitute(y)), ")", sep="")
@@ -405,11 +411,15 @@ loglogplot0 <- function(x,  ...)
    M <- data.frame(x,y)
   invisible(M)
 } 
-#-------------------------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # a function for ecdf the the difference that it divide by n+1
 # Mikis 9-1-2010 added weights
-# 
-ECDF <- function (y, weights=NULL) 
+################################################################################
+################################################################################
+ECDF <- function (y, weights=NULL)
 {
 if (is.null(weights))
   {
@@ -423,46 +433,71 @@ if (is.null(weights))
   {
     if (length(weights)!=length(y)) stop("y and weights have different length")
     i <- is.na(weights) | weights == 0
-    if (any(i)) 
+    if (any(i))
     {
       y <- y[!i]
 weights <- weights[!i]
-    } 
+    }
   ysort <- unique(sort(y))
-      n <- length(y)       
+      n <- length(y)
 weights <- tapply(weights, y, sum)
    cumu <- cumsum(weights)
    ecdf <- (cumu)/(cumu[length(cumu)]+1)
     fun <- stepfun(ysort, c(0, ecdf))
   class(fun) <- c("ecdf", "stepfun")
     return(fun)
+  }
+}
+################################################################################
+################################################################################
+################################################################################
+################################################################################
+ESURV <- function (y, weights=NULL) 
+{
+  if (is.null(weights))
+  {
+    ysort <- unique(sort(y))
+        n <- length(y)
+     esurv <- 1-cumsum(tabulate(match(y, ysort)))/(n + 1)
+       fun <- stepfun(ysort, c(1, esurv))
+class(fun) <- c("esurv", "stepfun")
+    return(fun)
+  } else
+  {
+if (length(weights)!=length(y)) stop("y and weights have different length")
+      i <- is.na(weights) | weights == 0
+if (any(i)) 
+    {
+            y <- y[!i]
+      weights <- weights[!i]
+    } 
+        ysort <- unique(sort(y))
+            n <- length(y)       
+      weights <- tapply(weights, y, sum)
+         cumu <- cumsum(weights)
+         esurv <- 1-(cumu)/(cumu[length(cumu)]+1)
+    fun <- stepfun(ysort, c(1, esurv))
+    class(fun) <- c("esurv", "stepfun")
+    return(fun)
   }   
 }  
-# ECDF <- function(y)
-# {
-#   ysort <- unique(sort(y))
-#       n <- length(y)
-# # ecdf0 <- cumsum(tabulate(match(y, ysort)))/n# standard definition
-#    ecdf <- cumsum(tabulate(match(y, ysort)))/(n+1)
-#   fun <- stepfun(ysort,c(0,ecdf))
-#   class(fun) <- c("ecdf", "stepfun")
-#   fun
-# }
-# --------------------------------------------------------------
 # --------------------------------------------------------------
 # this function is not exported 
 #---------------------------------------------------------------
-#---------------------------------------------------------------
+################################################################################
+################################################################################
+################################################################################
+################################################################################
 # This function allow weighted quantiles
 # It is bsed on the function wtd.quantile() of package Hmisc
-quantile.weights <- function (y, weights = NULL, probs = c(0, 0.25, 0.5, 0.75, 1)) 
+quantile_weights <- function (y, weights = NULL, probs = c(0, 0.25, 0.5, 0.75, 1))
 {
-  if (!length(weights)) 
+  if (!length(weights))
     return(quantile(y, probs = probs))
-  if (any(probs < 0 | probs > 1)) 
+  if (any(probs < 0 | probs > 1))
     stop("Probabilities must be between 0 and 1 inclusive")
   i <- is.na(weights) | weights == 0
-  if (any(i)) 
+  if (any(i))
   {
     y <- y[!i]
     weights <- weights[!i]
@@ -477,13 +512,17 @@ quantile.weights <- function (y, weights = NULL, probs = c(0, 0.25, 0.5, 0.75, 1
   low <- pmax(floor(order), 1)
   high <- pmin(low + 1, n)
   order <- order%%1
-  allq <- approx(cumsum(wts), x, xout = c(low, high), method = "constant", 
+  allq <- approx(cumsum(wts), x, xout = c(low, high), method = "constant",
                  f = 1, rule = 2)$y
   k <- length(probs)
   quantiles <- (1 - order) * allq[1:k] + order * allq[-(1:k)]
-  nams <- paste(format(round(probs * 100, 
-                             if (length(probs) > 1) 2 - log10(diff(range(probs))) else 2)), "%", sep = "")
+  nams <- paste(format(round(probs * 100,
+            if (length(probs) > 1) 2 - log10(diff(range(probs))) else 2)),
+            "%", sep = "")
   names(quantiles) <- nams
-  return(quantiles)  
+  return(quantiles)
 }
-#------------------------------------------------------------------------------
\ No newline at end of file
+################################################################################
+################################################################################
+################################################################################
+################################################################################
